@@ -2,6 +2,7 @@
 utils::globalVariables(c("xn", "vld", "conf.low", "conf.high"))
 
 #' @importFrom dplyr filter
+#' @importFrom sjstats merMod_p
 sjp.emm <- function(fit,
                     swap.pred = FALSE,
                     plevel = 0.05,
@@ -86,7 +87,7 @@ sjp.emm <- function(fit,
   # -----------------------------------------------------------
   if (is_mer_mod) {
     # get all p-values
-    pval <- get_lmerMod_pvalues(fit, KR = p.kr)[pos]
+    pval <- sjstats::merMod_p(fit, p.kr)[pos]
   } else {
     # retrieve p-values
     pval <- summary(fit)$coefficients[pos, 4]
