@@ -1,7 +1,3 @@
-# bind global variables
-utils::globalVariables(c("starts_with"))
-
-
 #' @title Summary of linear regression as HTML table
 #' @name sjt.lm
 #' 
@@ -70,12 +66,12 @@ utils::globalVariables(c("starts_with"))
 #'          abbreviations for estimates, std. beta-values, confidence interval and p-values.
 #' @param show.r2 logical, if \code{TRUE} (default), the R2 and adjusted R2 values for each model are printed
 #'          in the model summary. For linear mixed models, the R2 and Omega-squared values are printed
-#'          (see \code{\link[sjmisc]{r2}} for details).
+#'          (see \code{\link[sjstats]{r2}} for details).
 #' @param show.icc logical, if \code{TRUE}, the intra-class-correlation for each 
 #'          model is printed in the model summary. Only applies to mixed models.
 #' @param show.re.var logical, if \code{TRUE}, the variance parameters for the random
 #'          effects for each model are printed in the model summary. Only applies to mixed models.
-#'          For details output, see 'Note' in \code{\link[sjmisc]{icc}}.
+#'          For details output, see 'Note' in \code{\link[sjstats]{icc}}.
 #' @param show.fstat If \code{TRUE}, the F-statistics for each model is printed
 #'          in the model summary. Default is \code{FALSE}.
 #' @param show.aic logical, if \code{TRUE}, the AIC value for each model is printed
@@ -97,6 +93,11 @@ utils::globalVariables(c("starts_with"))
 #'          cell spacing, which would be: \code{CSS = list(css.thead = "padding:0.2cm;", css.tdata = "padding:0.2cm;")}.
 #' @param cell.gpr.indent indent for table rows with grouped factor predictors. Only applies
 #'          if \code{group.pred = TRUE}.
+#' @param sep.column logical, if \code{TRUE}, an empty table column is added after 
+#'          each model column, to add margins between model columns. By default, this
+#'          column will be added to the output; however, when copying tables to 
+#'          office applications, it might be helpful not to add this separator column
+#'          when modifying the table layout. 
 #'          
 #' @inheritParams sjt.frq
 #' @inheritParams sjp.lmer
@@ -280,6 +281,7 @@ utils::globalVariables(c("starts_with"))
 #' @importFrom dplyr full_join slice
 #' @importFrom stats nobs AIC confint coef deviance
 #' @importFrom lme4 VarCorr
+#' @importFrom sjstats std_beta icc r2 cod chisq_gof hoslem_gof
 #' @export
 sjt.lm <- function(...,
                    pred.labels = NULL,
@@ -323,6 +325,7 @@ sjt.lm <- function(...,
                    digits.summary = 3,
                    cell.spacing = 0.2,
                    cell.gpr.indent = 0.6,
+                   sep.column = TRUE,
                    CSS = NULL,
                    encoding = NULL,
                    file = NULL,
@@ -388,9 +391,6 @@ sjt.lm <- function(...,
   # do we have mixed models?
   # ------------------------
   lmerob <- any(class(input_list[[1]]) == "lmerMod") || any(class(input_list[[1]]) == "merModLmerTest")
-  if (lmerob && !requireNamespace("lme4", quietly = TRUE)) {
-    stop("Package `lme4` needed for this function to work. Please install it.", call. = FALSE)
-  }
   # ------------------------
   # should AICc be computed? Check for package
   # ------------------------
@@ -450,7 +450,7 @@ sjt.lm <- function(...,
     if (lmerob) {
       # get cleaned CI
       confis <- get_cleaned_ciMerMod(fit, "lm", T)
-      sbmer <- suppressWarnings(sjmisc::std_beta(fit)[-1, ])
+      sbmer <- suppressWarnings(sjstats::std_beta(fit)[-1, ])
       sbvals <- data.frame(beta = sbmer[, 1], 
                            ci.low = sbmer[, 1] - 1.96 * sbmer[, 2],
                            ci.hi = sbmer[, 1] + 1.96 * sbmer[, 2],
@@ -459,9 +459,9 @@ sjt.lm <- function(...,
     } else {
       confis <- stats::confint(fit)
       if (!is.null(show.std) && show.std == "std2") 
-        sbvals <- suppressWarnings(sjmisc::std_beta(fit, include.ci = T, type = "std2"))
+        sbvals <- suppressWarnings(sjstats::std_beta(fit, include.ci = T, type = "std2"))
       else
-        sbvals <- suppressWarnings(sjmisc::std_beta(fit, include.ci = T))
+        sbvals <- suppressWarnings(sjstats::std_beta(fit, include.ci = T))
       coef.fit <- stats::coef(fit)
     }
     # -------------------------------------
@@ -479,7 +479,7 @@ sjt.lm <- function(...,
     # -------------------------------------
     if (lmerob) {
       # p-values
-      fit.df$pv <- round(get_lmerMod_pvalues(fit, p.kr), digits.p)
+      fit.df$pv <- round(sjstats::merMod_p(fit, p.kr), digits.p)
       # standard error
       fit.df$se <- sprintf("%.*f", digits.se, stats::coef(summary(fit))[, "Std. Error"])
     } else {
@@ -623,7 +623,8 @@ sjt.lm <- function(...,
   # the column span over all models together; furthermore, we add
   # count of models to the overall column span, because
   # each model is separated with an empty table column
-  headerColSpan <- headerColSpanFactor * headerColSpan + length(input_list)
+  headerColSpan <- headerColSpanFactor * headerColSpan
+  if (sep.column) headerColSpan <- headerColSpan + length(input_list)
   linebreakstring <- " "
   if (newline.ci) linebreakstring <- "<br>"
   # -------------------------------------
@@ -654,8 +655,7 @@ sjt.lm <- function(...,
   # -------------------------------------
   # set default dependent var label
   # -------------------------------------
-  gtrl <- get_table_response_label(page.content, depvar.labels, 
-                                   input_list, tcp, headerColSpanFactor)
+  gtrl <- get_table_response_label(page.content, depvar.labels, input_list, tcp, headerColSpanFactor, sep.column)
   page.content <- gtrl$page.content
   depvar.labels <- gtrl$depvar.labels
   # -------------------------------------
@@ -668,7 +668,7 @@ sjt.lm <- function(...,
       # -------------------------
       # insert "separator column"
       # -------------------------
-      page.content <- paste0(page.content, "<td class=\"separatorcol colnames\">&nbsp;</td>")
+      if (sep.column) page.content <- paste0(page.content, "<td class=\"separatorcol colnames\">&nbsp;</td>")
       # confidence interval in separate column
       if (show.est) {
         if (separate.ci.col) {
@@ -756,7 +756,7 @@ sjt.lm <- function(...,
     # -------------------------
     # insert "separator column"
     # -------------------------
-    page.content <- paste0(page.content, sprintf("<td class=\"separatorcol %s\">&nbsp;</td>", tcb_class))
+    if (sep.column) page.content <- paste0(page.content, sprintf("<td class=\"separatorcol %s\">&nbsp;</td>", tcb_class))
     # show estimates?
     if (show.est) {
       # confidence interval in separate column
@@ -839,7 +839,7 @@ sjt.lm <- function(...,
       # -------------------------
       # insert "separator column"
       # -------------------------
-      page.content <- paste0(page.content, "<td class=\"separatorcol\">&nbsp;</td>")
+      if (sep.column) page.content <- paste0(page.content, "<td class=\"separatorcol\">&nbsp;</td>")
       # show estimates?
       if (show.est) {
         # retieve lower and upper ci
@@ -977,7 +977,7 @@ sjt.lm <- function(...,
         # -------------------------
         # insert "separator column"
         # -------------------------
-        page.content <- paste0(page.content, "<td class=\"separatorcol\">&nbsp;</td>")
+        if (sep.column) page.content <- paste0(page.content, "<td class=\"separatorcol\">&nbsp;</td>")
         sigma_2.var <- paste0(sprintf("%.*f", digits.summary, attr(reva, "sc") ^ 2, collapse = ""))
         page.content <- paste0(page.content, colspanstring, sigma_2.var, "</td>\n")
       }
@@ -996,7 +996,7 @@ sjt.lm <- function(...,
           # -------------------------
           # insert "separator column"
           # -------------------------
-          page.content <- paste0(page.content, "<td class=\"separatorcol\">&nbsp;</td>")
+          if (sep.column) page.content <- paste0(page.content, "<td class=\"separatorcol\">&nbsp;</td>")
           # get random intercept variance
           reva <- lme4::VarCorr(input_list[[i]])
           vars <- lapply(reva, function(x) x[[1]])
@@ -1022,7 +1022,7 @@ sjt.lm <- function(...,
           # -------------------------
           # insert "separator column"
           # -------------------------
-          page.content <- paste0(page.content, "<td class=\"separatorcol\">&nbsp;</td>")
+          if (sep.column) page.content <- paste0(page.content, "<td class=\"separatorcol\">&nbsp;</td>")
           # does model have random slope?
           if (has_rnd_slope[i]) {
             # get slope-intercept correlation
@@ -1049,7 +1049,7 @@ sjt.lm <- function(...,
         # -------------------------
         # insert "separator column"
         # -------------------------
-        page.content <- paste0(page.content, "<td class=\"separatorcol\">&nbsp;</td>")
+        if (sep.column) page.content <- paste0(page.content, "<td class=\"separatorcol\">&nbsp;</td>")
         # retrieve random intercepts of each model
         sub.mmgrps <- lme4::getME(input_list[[i]], "flist")
         # does model have enough random intercepts?
@@ -1069,7 +1069,7 @@ sjt.lm <- function(...,
     # -------------------------------------
     if (show.icc) {
       # get icc from models
-      summary.icc <- sjmisc::icc(input_list[[which.max(all_mm_counts)]])
+      summary.icc <- sjstats::icc(input_list[[which.max(all_mm_counts)]])
       # iterate icc's
       for (si in 1:mmcount) {
         page.content <- paste0(page.content, sprintf("  <tr>\n    <td class=\"tdata leftalign summary\">ICC<sub>%s</sub></td>\n", names(summary.icc[si])))
@@ -1078,9 +1078,9 @@ sjt.lm <- function(...,
           # -------------------------
           # insert "separator column"
           # -------------------------
-          page.content <- paste0(page.content, "<td class=\"separatorcol\">&nbsp;</td>")
+          if (sep.column) page.content <- paste0(page.content, "<td class=\"separatorcol\">&nbsp;</td>")
           # get icc from models
-          sub.summary.icc <- sjmisc::icc(input_list[[i]])
+          sub.summary.icc <- sjstats::icc(input_list[[i]])
           # does model have enough icc values?
           # if yes, print
           if (length(sub.summary.icc) >= si) {
@@ -1102,7 +1102,7 @@ sjt.lm <- function(...,
     # -------------------------
     # insert "separator column"
     # -------------------------
-    page.content <- paste0(page.content, "<td class=\"separatorcol firstsumrow\">&nbsp;</td>")
+    if (sep.column) page.content <- paste0(page.content, "<td class=\"separatorcol firstsumrow\">&nbsp;</td>")
     # -------------------------------------
     # get number of observations
     # -------------------------------------
@@ -1130,7 +1130,7 @@ sjt.lm <- function(...,
       # -------------------------
       # insert "separator column"
       # -------------------------
-      page.content <- paste0(page.content, "\n    <td class=\"separatorcol\">&nbsp;</td>")
+      if (sep.column) page.content <- paste0(page.content, "\n    <td class=\"separatorcol\">&nbsp;</td>")
       # -------------------------
       # no R2 for GLS
       # -------------------------
@@ -1138,7 +1138,7 @@ sjt.lm <- function(...,
         page.content <- paste0(page.content, sprintf("    %sNA / NA</td>\n", colspanstring))
       } else {
         # get r2 values
-        r2vals <- sjmisc::r2(input_list[[i]])
+        r2vals <- sjstats::r2(input_list[[i]])
         page.content <- paste0(page.content, gsub("0.", 
                                                   paste0(p_zero, "."), 
                                                   sprintf("    %s%.*f / %.*f</td>\n", 
@@ -1161,7 +1161,7 @@ sjt.lm <- function(...,
       # -------------------------
       # insert "separator column"
       # -------------------------
-      page.content <- paste0(page.content, "\n    <td class=\"separatorcol\">&nbsp;</td>")
+      if (sep.column) page.content <- paste0(page.content, "\n    <td class=\"separatorcol\">&nbsp;</td>")
       # -------------------------
       # no F-Statistics for GLS
       # -------------------------
@@ -1189,12 +1189,22 @@ sjt.lm <- function(...,
   # Model-Summary: AIC
   # -------------------------------------
   if (show.aic) {
+    # -------------------------------------
+    # Check whether we have mixed models, and fitted with REML.
+    # In this case, comparison of AIC does not make sense -
+    # user need to refit models with REML = FALSE
+    # -------------------------------------
+    if (lmerob && length(input_list) > 1) {
+      # check whether we have mixed models fitted with REML
+      models.reml <- vapply(input_list, function(x) is(x, "merMod") && lme4::isREML(x), NA)
+      if (any(models.reml)) warning("Some models were fit with REML. To get meaningful AIC values for comparison, refit models with ML (`REML = FALSE`).", call. = F)
+    }
     page.content <- paste(page.content, "  <tr>\n     <td class=\"tdata leftalign summary\">AIC</td>\n")
     for (i in 1:length(input_list)) {
       # -------------------------
       # insert "separator column"
       # -------------------------
-      page.content <- paste0(page.content, "\n    <td class=\"separatorcol\">&nbsp;</td>")
+      if (sep.column) page.content <- paste0(page.content, "\n    <td class=\"separatorcol\">&nbsp;</td>")
       page.content <- paste(page.content, sprintf("    %s%.*f</td>\n", colspanstring, digits.summary, stats::AIC(input_list[[i]])))
     }
     page.content <- paste0(page.content, "  </tr>\n")
@@ -1208,7 +1218,7 @@ sjt.lm <- function(...,
       # -------------------------
       # insert "separator column"
       # -------------------------
-      page.content <- paste0(page.content, "\n    <td class=\"separatorcol\">&nbsp;</td>")
+      if (sep.column) page.content <- paste0(page.content, "\n    <td class=\"separatorcol\">&nbsp;</td>")
       page.content <- paste(page.content, sprintf("    %s%.*f</td>\n", colspanstring, digits.summary, AICcmodavg::AICc(input_list[[i]])))
     }
     page.content <- paste0(page.content, "  </tr>\n")
@@ -1222,7 +1232,7 @@ sjt.lm <- function(...,
       # -------------------------
       # insert "separator column"
       # -------------------------
-      page.content <- paste0(page.content, "<td class=\"separatorcol\">&nbsp;</td>")
+      if (sep.column) page.content <- paste0(page.content, "<td class=\"separatorcol\">&nbsp;</td>")
       page.content <- paste0(page.content, sprintf("%s%.*f</td>", colspanstring, digits.summary, stats::deviance(input_list[[i]], REML = FALSE)))
     }
     page.content <- paste0(page.content, "\n  </tr>\n")
@@ -1305,7 +1315,7 @@ sjt.lm <- function(...,
 #'         the \pkg{pbkrtest}-package. If \pkg{pbkrtest} is not available or
 #'         \code{p.kr = FALSE}, computation of p-values is based 
 #'         on normal-distribution assumption, treating the t-statistics as Wald
-#'         z-statistics.
+#'         z-statistics. See 'Details' in \code{\link[sjstats]{merMod_p}}.
 #'         \cr \cr
 #'         The variance components of the random parts (see \code{show.re.var}) are
 #'         denoted like:
@@ -1412,6 +1422,7 @@ sjt.lmer <- function(...,
                      digits.summary = 3,
                      cell.spacing = 0.2,
                      cell.gpr.indent = 0.6,
+                     sep.column = TRUE,
                      CSS = NULL,
                      encoding = NULL,
                      file = NULL,
@@ -1433,6 +1444,7 @@ sjt.lmer <- function(...,
                 separate.ci.col = separate.ci.col, newline.ci = newline.ci, 
                 group.pred = group.pred, show.col.header = show.col.header, show.r2 = show.r2, show.icc = show.icc, 
                 show.re.var = show.re.var, show.fstat = FALSE, show.aic = show.aic, show.aicc = show.aicc, show.dev = show.dev,
-                remove.estimates = remove.estimates, cell.spacing = cell.spacing, cell.gpr.indent = cell.gpr.indent, encoding = encoding, 
+                remove.estimates = remove.estimates, cell.spacing = cell.spacing, cell.gpr.indent = cell.gpr.indent,
+                sep.column = sep.column, encoding = encoding, 
                 CSS = CSS, use.viewer = use.viewer, no.output = no.output, remove.spaces = remove.spaces))
 }
\ No newline at end of file
